Index: /fmts/trunk/p/C0XRDF.m
===================================================================
--- /fmts/trunk/p/C0XRDF.m	(revision 1390)
+++ /fmts/trunk/p/C0XRDF.m	(revision 1391)
@@ -43,4 +43,6 @@
  . S ZA=$P(ZPRED,":",1)
  . S ZB=$P(ZPRED,":",2)
+ . I $E(ZB,1,1)="/" D  ;
+ . . S ZB=$P(ZB,"/",2) ; handling gpltest:/note situations
  . S ZC=C0XVOC(ZA)
  . I ZOBJ["nodeID:" D  Q  ;

Index: /fmts/trunk/p/C0XGET1.m
===================================================================
--- /fmts/trunk/p/C0XGET1.m	(revision 1390)
+++ /fmts/trunk/p/C0XGET1.m	(revision 1391)
@@ -109,6 +109,6 @@
  ;
 getGraph(zrtn,zgrf,form) ; get all triples in graph zgrf
  ; forms planned: "rdf" "json" "array" "turtle" "triples"
  ; forms supported: "rdf" "json" "array"
  I '$D(form) S form="rdf"
  N ZIENS,ZTRIP
@@ -119,4 +119,5 @@
  i form="rdf" d rdfout^C0XRDF(.zrtn,.ZTRIP) q  ;
  i form="array" d arrayout^C0XGET1(.zrtn,.ZTRIP) q  ;
+ i form="raw" d rawout^C0XGET1(.zrtn,.ZTRIP) q  ;
  W !,"Form not supported: ",form
  Q
@@ -157,5 +158,6 @@
  i form="json" d jsonout(.triplertn,.zrary) q  ; what follows is 'else'
  i form="rdf" d rdfout^C0XRDF(.triplertn,.zrary) q  ;
- i form="array" d arrayout(.triplertn,.zrary) q ;
+ i form="array" d arrayout(.triplertn,.zrary) q  ;
+ i form="raw" d rawout(.triplertn,.zrary) q  ;
  w !,"form not supported: ",form 
  q
@@ -283,4 +285,15 @@
  q
  ;
+rawout(rtn,zary) ; output a mumps array of triples
+ ;
+ s zrsub=""
+ ;s zcnt=1
+ f  s zrsub=$o(zary(zrsub)) q:zrsub=""  d  ; organized by subject
+ . s zzz=""
+ . f  s zzz=$o(zary(zrsub,zzz)) q:zzz=""  d  ; pred and obj
+ . . s rtn(zrsub,$p(zzz,"^",1))=$p(zzz,"^",2)
+ . . ;s zcnt=zcnt+1
+ q
+ ;
 strings(zrary,zinary) ; convert pointers to strings
  ;
@@ -109,6 +109,6 @@
  ;
 getGraph(zrtn,zgrf,form) ; get all triples in graph zgrf
- ; forms planned: "rdf" "json" "array" "turtle" "triples"
- ; forms supported: "rdf" "json" "array"
+ ; forms planned: "rdf" "json" "array" "turtle" "triples" "raw"
+ ; forms supported: "rdf" "json" "array" "raw"
  I '$D(form) S form="rdf"
  N ZIENS,ZTRIP